@@ -45,10 +45,14 @@ def route(module=None, name=None, permission=True, ajax=True, referer=None, **kw
                 )
             )
 
-            # 调用中间件以检查登录状态以及用户权限
-            result = mgr.invoke()
+            # 处理请求中的json参数
+            # 处理后可能会在 request 上添加一个 json 的项，此项存放着json格式的 body 内容
+            _process_json_params(request)
 
-            # 返回了 HttpResponse ， 直接返回此对象
+            # 调用中间件，以处理请求
+            result = mgr.begin()
+
+            # 返回了 HttpResponse，直接返回此对象
             if isinstance(result, HttpResponse):
                 return mgr.end(result)
 
@@ -56,12 +60,6 @@ def route(module=None, name=None, permission=True, ajax=True, referer=None, **kw
             if result is False:
                 return mgr.end(HttpResponseUnauthorized())
 
-            # 处理请求中的json参数
-            # 处理后可能会在 request 上添加一个 json 的项，此项存放着json格式的 body 内容
-            _process_json_params(request)
-
-            result = mgr.params()
-
             # 返回了 HttpResponse ， 直接返回此对象
             if isinstance(result, HttpResponse):
                 return mgr.end(result)
@@ -156,7 +154,7 @@ def _get_value(data: dict, name: str, arg_spec: ArgumentSpecification, signature
     return None, None
 
 
-def _get_actual_args(request: HttpRequest, func, args: OrderedDict) -> dict:
+def _get_actual_args(request: HttpRequest, func, args: OrderedDict) -> dict or HttpResponse:
     method = request.method.lower()
     actual_args = {}
 
